#[repr(i32)]pub enum BluetoothDeviceRequestType {
Connect = 0,
Disconnect = 1,
Pair = 2,
Unpair = 3,
ConnectV3WithCache = 4,
ConnectV3WithoutCache = 5,
ClearCache = 6,
}Variants
Connect = 0
👎Deprecated
V1 removed, use V3 variants
Disconnect = 1
Pair = 2
Unpair = 3
ConnectV3WithCache = 4
ConnectV3WithoutCache = 5
ClearCache = 6
Implementations
Sourceimpl BluetoothDeviceRequestType
impl BluetoothDeviceRequestType
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of BluetoothDeviceRequestType.
Sourcepub fn from_i32(value: i32) -> Option<BluetoothDeviceRequestType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<BluetoothDeviceRequestType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a BluetoothDeviceRequestType, or None if value is not a valid variant.
Sourceimpl BluetoothDeviceRequestType
impl BluetoothDeviceRequestType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.