#[repr(i32)]pub enum LegacyCoverState {
Open = 0,
Closed = 1,
}Expand description
Deprecated in API version 1.1
Variants
Implementations
Sourceimpl LegacyCoverState
impl LegacyCoverState
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of LegacyCoverState.
Sourcepub fn from_i32(value: i32) -> Option<LegacyCoverState>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<LegacyCoverState>
Use the TryFrom<i32> implementation instead
Converts an i32 to a LegacyCoverState, or None if value is not a valid variant.
Sourceimpl LegacyCoverState
impl LegacyCoverState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.