#[repr(i32)]pub enum MediaPlayerCommand {
Show 14 variants
Play = 0,
Pause = 1,
Stop = 2,
Mute = 3,
Unmute = 4,
Toggle = 5,
VolumeUp = 6,
VolumeDown = 7,
Enqueue = 8,
RepeatOne = 9,
RepeatOff = 10,
ClearPlaylist = 11,
TurnOn = 12,
TurnOff = 13,
}Variants
Play = 0
Pause = 1
Stop = 2
Mute = 3
Unmute = 4
Toggle = 5
VolumeUp = 6
VolumeDown = 7
Enqueue = 8
RepeatOne = 9
RepeatOff = 10
ClearPlaylist = 11
TurnOn = 12
TurnOff = 13
Implementations
Sourceimpl MediaPlayerCommand
impl MediaPlayerCommand
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of MediaPlayerCommand.
Sourcepub fn from_i32(value: i32) -> Option<MediaPlayerCommand>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<MediaPlayerCommand>
Use the TryFrom<i32> implementation instead
Converts an i32 to a MediaPlayerCommand, or None if value is not a valid variant.
Sourceimpl MediaPlayerCommand
impl MediaPlayerCommand
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.