#[repr(i32)]pub enum SerialProxyRequestType {
Subscribe = 0,
Unsubscribe = 1,
Flush = 2,
}Variants
Subscribe = 0
Subscribe to receive data from this serial proxy instance
Unsubscribe = 1
Unsubscribe from this serial proxy instance
Flush = 2
Flush the serial port (block until all TX data is sent)
Implementations
Sourceimpl SerialProxyRequestType
impl SerialProxyRequestType
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of SerialProxyRequestType.
Sourcepub fn from_i32(value: i32) -> Option<SerialProxyRequestType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<SerialProxyRequestType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a SerialProxyRequestType, or None if value is not a valid variant.
Sourceimpl SerialProxyRequestType
impl SerialProxyRequestType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.