#[repr(i32)]pub enum SerialProxyStatus {
Ok = 0,
AssumedSuccess = 1,
Error = 2,
Timeout = 3,
NotSupported = 4,
}Variants
Ok = 0
Completed successfully; TX drain confirmed
AssumedSuccess = 1
Platform cannot confirm TX drain; success assumed
Error = 2
Driver or hardware error
Timeout = 3
Timed out before TX completed
NotSupported = 4
Request type not supported by this instance
Implementations
Sourceimpl SerialProxyStatus
impl SerialProxyStatus
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of SerialProxyStatus.
Sourcepub fn from_i32(value: i32) -> Option<SerialProxyStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<SerialProxyStatus>
Use the TryFrom<i32> implementation instead
Converts an i32 to a SerialProxyStatus, or None if value is not a valid variant.
Sourceimpl SerialProxyStatus
impl SerialProxyStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.