pub struct AuthenticationRequest {
pub password: String,
}Expand description
DEPRECATED in ESPHome 2026.1.0 - Password authentication is no longer supported. These messages are kept for protocol documentation but are not processed by the server. Use noise encryption instead: https://esphome.io/components/api/#configuration-variables
Fields
password: StringTrait Implementations
Sourceimpl Clone for AuthenticationRequest
impl Clone for AuthenticationRequest
Sourcefn clone(&self) -> AuthenticationRequest
fn clone(&self) -> AuthenticationRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuthenticationRequest
impl Debug for AuthenticationRequest
Sourceimpl Default for AuthenticationRequest
impl Default for AuthenticationRequest
impl Eq for AuthenticationRequest
Sourceimpl From<AuthenticationRequest> for EspHomeMessage
impl From<AuthenticationRequest> for EspHomeMessage
Sourcefn from(msg: AuthenticationRequest) -> Self
fn from(msg: AuthenticationRequest) -> Self
Converts to this type from the input type.
Sourceimpl Hash for AuthenticationRequest
impl Hash for AuthenticationRequest
Sourceimpl Message for AuthenticationRequest
impl Message for AuthenticationRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for AuthenticationRequest
impl PartialEq for AuthenticationRequest
Sourcefn eq(&self, other: &AuthenticationRequest) -> bool
fn eq(&self, other: &AuthenticationRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AuthenticationRequest