pub struct BluetoothGattErrorResponse {
pub address: u64,
pub handle: u32,
pub error: i32,
}Fields
address: u64handle: u32error: i32Trait Implementations
Sourceimpl Clone for BluetoothGattErrorResponse
impl Clone for BluetoothGattErrorResponse
Sourcefn clone(&self) -> BluetoothGattErrorResponse
fn clone(&self) -> BluetoothGattErrorResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for BluetoothGattErrorResponse
Sourceimpl Debug for BluetoothGattErrorResponse
impl Debug for BluetoothGattErrorResponse
Sourceimpl Default for BluetoothGattErrorResponse
impl Default for BluetoothGattErrorResponse
impl Eq for BluetoothGattErrorResponse
Sourceimpl From<BluetoothGattErrorResponse> for EspHomeMessage
impl From<BluetoothGattErrorResponse> for EspHomeMessage
Sourcefn from(msg: BluetoothGattErrorResponse) -> Self
fn from(msg: BluetoothGattErrorResponse) -> Self
Converts to this type from the input type.
Sourceimpl Hash for BluetoothGattErrorResponse
impl Hash for BluetoothGattErrorResponse
Sourceimpl Message for BluetoothGattErrorResponse
impl Message for BluetoothGattErrorResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BluetoothGattErrorResponse
impl PartialEq for BluetoothGattErrorResponse
Sourcefn eq(&self, other: &BluetoothGattErrorResponse) -> bool
fn eq(&self, other: &BluetoothGattErrorResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BluetoothGattErrorResponse