pub struct DstRule {
pub time_seconds: i32,
pub day: u32,
pub type: i32,
pub month: u32,
pub week: u32,
pub day_of_week: u32,
}Fields
time_seconds: i32day: u32type: i32month: u32week: u32day_of_week: u32Implementations
Sourceimpl DstRule
impl DstRule
Sourcepub fn type(&self) -> DstRuleType
pub fn type(&self) -> DstRuleType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: DstRuleType)
pub fn set_type(&mut self, value: DstRuleType)
Sets type to the provided enum value.