pub struct ExecuteServiceResponse {
pub call_id: u32,
pub success: bool,
pub error_message: String,
pub response_data: Vec<u8>,
}Expand description
Message sent by ESPHome to Home Assistant with service execution response data
Fields
call_id: u32Matches the call_id from ExecuteServiceRequest
success: boolWhether the service execution succeeded
error_message: StringError message if success = false
response_data: Vec<u8>Trait Implementations
Sourceimpl Clone for ExecuteServiceResponse
impl Clone for ExecuteServiceResponse
Sourcefn clone(&self) -> ExecuteServiceResponse
fn clone(&self) -> ExecuteServiceResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecuteServiceResponse
impl Debug for ExecuteServiceResponse
Sourceimpl Default for ExecuteServiceResponse
impl Default for ExecuteServiceResponse
impl Eq for ExecuteServiceResponse
Sourceimpl From<ExecuteServiceResponse> for EspHomeMessage
impl From<ExecuteServiceResponse> for EspHomeMessage
Sourcefn from(msg: ExecuteServiceResponse) -> Self
fn from(msg: ExecuteServiceResponse) -> Self
Converts to this type from the input type.
Sourceimpl Hash for ExecuteServiceResponse
impl Hash for ExecuteServiceResponse
Sourceimpl Message for ExecuteServiceResponse
impl Message for ExecuteServiceResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ExecuteServiceResponse
impl PartialEq for ExecuteServiceResponse
Sourcefn eq(&self, other: &ExecuteServiceResponse) -> bool
fn eq(&self, other: &ExecuteServiceResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExecuteServiceResponse