pub struct HelloResponse {
pub api_version_major: u32,
pub api_version_minor: u32,
pub server_info: String,
pub name: String,
}Expand description
Confirmation of successful connection request. Can only be sent by the server and only at the beginning of the connection
Fields
api_version_major: u32The version of the API to use. The client (for example Home Assistant) needs to check for compatibility and if necessary adopt to an older API. Major is for breaking changes in the base protocol - a mismatch will lead to immediate disconnect_client_ Minor is for breaking changes in individual messages - a mismatch will lead to a warning message
api_version_minor: u32server_info: StringA string identifying the server (ESP); like client info this may be empty and only exists for debugging/logging purposes. Currently set to ESPHOME_VERSION string literal.
name: StringThe name of the server (App.get_name() - device hostname) max_data_length matches ESPHOME_DEVICE_NAME_MAX_LEN (validated by validate_hostname)