pub struct HomeassistantActionResponse {
pub call_id: u32,
pub success: bool,
pub error_message: String,
pub response_data: Vec<u8>,
}Expand description
Message sent by Home Assistant to ESPHome with service call response data
Fields
call_id: u32Matches the call_id from HomeassistantActionRequest
success: boolWhether the service call succeeded
error_message: StringError message if success = false
response_data: Vec<u8>Trait Implementations
Sourceimpl Clone for HomeassistantActionResponse
impl Clone for HomeassistantActionResponse
Sourcefn clone(&self) -> HomeassistantActionResponse
fn clone(&self) -> HomeassistantActionResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HomeassistantActionResponse
impl Debug for HomeassistantActionResponse
impl Eq for HomeassistantActionResponse
Sourceimpl From<HomeassistantActionResponse> for EspHomeMessage
impl From<HomeassistantActionResponse> for EspHomeMessage
Sourcefn from(msg: HomeassistantActionResponse) -> Self
fn from(msg: HomeassistantActionResponse) -> Self
Converts to this type from the input type.
Sourceimpl Hash for HomeassistantActionResponse
impl Hash for HomeassistantActionResponse
Sourceimpl Message for HomeassistantActionResponse
impl Message for HomeassistantActionResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for HomeassistantActionResponse
impl PartialEq for HomeassistantActionResponse
Sourcefn eq(&self, other: &HomeassistantActionResponse) -> bool
fn eq(&self, other: &HomeassistantActionResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for HomeassistantActionResponse