pub struct SerialProxyConfigureRequest {
pub instance: u32,
pub baudrate: u32,
pub flow_control: bool,
pub parity: i32,
pub stop_bits: u32,
pub data_size: u32,
}Expand description
Configure UART parameters for a serial proxy instance
Fields
instance: u32Instance index (0-based)
baudrate: u32Baud rate in bits per second
flow_control: boolEnable hardware flow control
parity: i32Parity setting
stop_bits: u32Number of stop bits (1 or 2)
data_size: u32Number of data bits (5-8)
Implementations
Sourceimpl SerialProxyConfigureRequest
impl SerialProxyConfigureRequest
Sourcepub fn parity(&self) -> SerialProxyParity
pub fn parity(&self) -> SerialProxyParity
Returns the enum value of parity, or the default if the field is set to an invalid enum value.
Sourcepub fn set_parity(&mut self, value: SerialProxyParity)
pub fn set_parity(&mut self, value: SerialProxyParity)
Sets parity to the provided enum value.