pub struct SerialProxyRequestResponse {
pub instance: u32,
pub type: i32,
pub status: i32,
pub error_message: String,
}Expand description
Response to a SerialProxyRequest (e.g. flush completion or failure)
Fields
instance: u32Instance index (0-based)
type: i32Which request type this responds to
status: i32Result status
error_message: StringAdditional detail on failure (optional)
Implementations
Sourceimpl SerialProxyRequestResponse
impl SerialProxyRequestResponse
Sourcepub fn type(&self) -> SerialProxyRequestType
pub fn type(&self) -> SerialProxyRequestType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: SerialProxyRequestType)
pub fn set_type(&mut self, value: SerialProxyRequestType)
Sets type to the provided enum value.
Sourcepub fn status(&self) -> SerialProxyStatus
pub fn status(&self) -> SerialProxyStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: SerialProxyStatus)
pub fn set_status(&mut self, value: SerialProxyStatus)
Sets status to the provided enum value.