pub struct WaterHeaterCommandRequest {
pub key: u32,
pub has_fields: u32,
pub mode: i32,
pub target_temperature: f32,
pub device_id: u32,
pub state: u32,
pub target_temperature_low: f32,
pub target_temperature_high: f32,
}Fields
key: u32has_fields: u32Bitmask of which fields are set (see WaterHeaterCommandHasField)
mode: i32target_temperature: f32device_id: u32state: u32State flags bitmask (bit 0 = away, bit 1 = on)
target_temperature_low: f32target_temperature_high: f32Implementations
Sourceimpl WaterHeaterCommandRequest
impl WaterHeaterCommandRequest
Sourcepub fn mode(&self) -> WaterHeaterMode
pub fn mode(&self) -> WaterHeaterMode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: WaterHeaterMode)
pub fn set_mode(&mut self, value: WaterHeaterMode)
Sets mode to the provided enum value.